@@ -19,7 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef _OGL_TEXTURE_H_
 #define _OGL_TEXTURE_H_
 
-#include <SDL_opengl.h>
+#include "osal_opengl.h"
 
 #include "TextureManager.h"
 
