@@ -17,6 +17,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#define M64P_PLUGIN_PROTOTYPES 1
 #include "osal_preproc.h"
 #include "m64p_plugin.h"
 
@@ -27,6 +28,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "liblinux/BMGLibPNG.h"
 
+#include <algorithm>
+
 extern FiddledVtx * g_pVtxBase;
 CRender * CRender::g_pRender=NULL;
 int CRender::gRenderReferenceCount=0;
@@ -39,6 +42,13 @@ extern char* right (const char * src, int nchars);
   #define strcasecmp _stricmp
 #endif
 
+#ifdef min
+#undef min
+#endif
+#ifdef max
+#undef max
+#endif
+
 //========================================================================
 CRender * CRender::GetRender(void)
 {
@@ -170,7 +180,6 @@ void CRender::SetProjection(const Matrix & mat, bool bPush, bool bReplace)
         {
             gRSP.projectionMtxs[gRSP.projectionMtxTop] = mat * gRSP.projectionMtxs[gRSP.projectionMtxTop];
         }
-
     }
     
     gRSP.bMatrixIsUpdated = true;
@@ -321,32 +330,32 @@ void CRender::RenderReset()
 
 bool CRender::FillRect(int nX0, int nY0, int nX1, int nY1, uint32 dwColor)
 {
-  LOG_UCODE("FillRect: X0=%d, Y0=%d, X1=%d, Y1=%d, Color=0x%8X", nX0, nY0, nX1, nY1, dwColor);
+    LOG_UCODE("FillRect: X0=%d, Y0=%d, X1=%d, Y1=%d, Color=0x%8X", nX0, nY0, nX1, nY1, dwColor);
 
-  if (g_CI.dwSize != TXT_SIZE_16b && frameBufferOptions.bIgnore) 
-    return true;
+    if (g_CI.dwSize != TXT_SIZE_16b && frameBufferOptions.bIgnore) 
+        return true;
 
-  if (status.bHandleN64RenderTexture && !status.bDirectWriteIntoRDRAM)
-     status.bFrameBufferIsDrawn = true;
+    if (status.bHandleN64RenderTexture && !status.bDirectWriteIntoRDRAM)
+        status.bFrameBufferIsDrawn = true;
 
-  if(status.bVIOriginIsUpdated == true && currentRomOptions.screenUpdateSetting==SCREEN_UPDATE_AT_1ST_PRIMITIVE)
-  {
-    status.bVIOriginIsUpdated=false;
-    CGraphicsContext::Get()->UpdateFrame();
-    DEBUGGER_PAUSE_AND_DUMP_NO_UPDATE(NEXT_SET_CIMG, {DebuggerAppendMsg("Screen Update at 1st FillRectangle");});
-  }
+    if(status.bVIOriginIsUpdated == true && currentRomOptions.screenUpdateSetting==SCREEN_UPDATE_AT_1ST_PRIMITIVE)
+    {
+        status.bVIOriginIsUpdated=false;
+        CGraphicsContext::Get()->UpdateFrame();
+        DEBUGGER_PAUSE_AND_DUMP_NO_UPDATE(NEXT_SET_CIMG, {DebuggerAppendMsg("Screen Update at 1st FillRectangle");});
+    }
 
   if (status.bCIBufferIsRendered && status.bVIOriginIsUpdated == true && currentRomOptions.screenUpdateSetting==SCREEN_UPDATE_BEFORE_SCREEN_CLEAR )
-    {
-    if ((nX0==0 && nY0 == 0 && (nX1 == (int) g_CI.dwWidth || nX1 == (int) g_CI.dwWidth-1)) ||
-        (nX0==gRDP.scissor.left && nY0 == gRDP.scissor.top  && (nX1 == gRDP.scissor.right || nX1 == gRDP.scissor.right-1)) ||
-        ((nX0+nX1 == (int)g_CI.dwWidth || nX0+nX1 == (int)g_CI.dwWidth-1 || nX0+nX1 == gRDP.scissor.left+gRDP.scissor.right || nX0+nX1 == gRDP.scissor.left+gRDP.scissor.right-1) && (nY0 == gRDP.scissor.top || nY0 == 0 || nY0+nY1 == gRDP.scissor.top+gRDP.scissor.bottom || nY0+nY1 == gRDP.scissor.top+gRDP.scissor.bottom-1)))
-        {
-            status.bVIOriginIsUpdated=false;
-            CGraphicsContext::Get()->UpdateFrame();
-            DEBUGGER_PAUSE_AND_DUMP_NO_UPDATE(NEXT_SET_CIMG,{DebuggerAppendMsg("Screen Update Before Screen Clear");});
-        }
-    }
+  {
+      if ((nX0==0 && nY0 == 0 && (nX1 == (int) g_CI.dwWidth || nX1 == (int) g_CI.dwWidth-1)) ||
+          (nX0==gRDP.scissor.left && nY0 == gRDP.scissor.top  && (nX1 == gRDP.scissor.right || nX1 == gRDP.scissor.right-1)) ||
+          ((nX0+nX1 == (int)g_CI.dwWidth || nX0+nX1 == (int)g_CI.dwWidth-1 || nX0+nX1 == gRDP.scissor.left+gRDP.scissor.right || nX0+nX1 == gRDP.scissor.left+gRDP.scissor.right-1) && (nY0 == gRDP.scissor.top || nY0 == 0 || nY0+nY1 == gRDP.scissor.top+gRDP.scissor.bottom || nY0+nY1 == gRDP.scissor.top+gRDP.scissor.bottom-1)))
+      {
+          status.bVIOriginIsUpdated=false;
+          CGraphicsContext::Get()->UpdateFrame();
+          DEBUGGER_PAUSE_AND_DUMP_NO_UPDATE(NEXT_SET_CIMG,{DebuggerAppendMsg("Screen Update Before Screen Clear");});
+      }
+  }
 
 
     SetFillMode(RICE_FILLMODE_SOLID);
@@ -592,7 +601,7 @@ bool CRender::TexRect(int nX0, int nY0, int nX1, int nY1, float fS0, float fT0,
     if( options.bEnableHacks )
     {
         // Goldeneye HACK
-        if( options.bEnableHacks && nY1 - nY0 < 2 ) 
+        if( nY1 - nY0 < 2 ) 
             nY1 = nY1+2;
 
         //// Text edge hack
@@ -624,7 +633,6 @@ bool CRender::TexRect(int nX0, int nY0, int nX1, int nY1, float fS0, float fT0,
 
     BOOL accurate = currentRomOptions.bAccurateTextureMapping;
 
-    CTexture *surf = g_textures[gRSP.curTile].m_pCTexture;
     RenderTexture &tex0 = g_textures[gRSP.curTile];
     Tile &tile0 = gRDP.tiles[gRSP.curTile];
 
@@ -724,7 +732,6 @@ bool CRender::TexRect(int nX0, int nY0, int nX1, int nY1, float fS0, float fT0,
 
     if( IsTexel1Enable() )
     {
-        surf = g_textures[(gRSP.curTile+1)&7].m_pCTexture;
         RenderTexture &tex1 = g_textures[(gRSP.curTile+1)&7];
         Tile &tile1 = gRDP.tiles[(gRSP.curTile+1)&7];
 
@@ -1217,7 +1224,6 @@ bool CRender::DrawTriangles()
     for( int t=0; t<2; t++ )
     {
         float halfscaleS = 1;
-        float halfscaleT = 1;
 
         // This will get rid of the thin black lines
         if( t==0 && !(m_pColorCombiner->m_bTex0Enabled) ) 
@@ -1230,16 +1236,15 @@ bool CRender::DrawTriangles()
                 && gRDP.tiles[0].dwFormat == TXT_FMT_CI && gRDP.tiles[0].dwSize == TXT_SIZE_8b && gRSP.curTile == 0 ))
             {
                 halfscaleS = 0.5;
-                halfscaleT = 0.5;
             }
         }
 
-        if( t==1 && !(m_pColorCombiner->m_bTex1Enabled) ) break;
+        if( t==1 && !(m_pColorCombiner->m_bTex1Enabled) )
+            break;
 
-        uint32 i;
         if( halfscaleS < 1 )
         {
-            for( i=0; i<gRSP.numVertices; i++ )
+            for( uint32 i=0; i<gRSP.numVertices; i++ )
             {
                 if( t == 0 )
                 {
@@ -1268,7 +1273,7 @@ bool CRender::DrawTriangles()
         bool clampS=true;
         bool clampT=true;
 
-        for( i=0; i<gRSP.numVertices; i++ )
+        for( uint32 i=0; i<gRSP.numVertices; i++ )
         {
             float w = CDeviceBuilder::GetGeneralDeviceType() == OGL_DEVICE ? g_vtxProjected5[i][3] : g_vtxBuffer[i].rhw; 
             if( w < 0 || g_vtxBuffer[i].tcord[t].u > 1.0 || g_vtxBuffer[i].tcord[t].u < 0.0  )
@@ -1278,7 +1283,7 @@ bool CRender::DrawTriangles()
             }
         }
 
-        for( i=0; i<gRSP.numVertices; i++ )
+        for( uint32 i=0; i<gRSP.numVertices; i++ )
         {
             float w = CDeviceBuilder::GetGeneralDeviceType() == OGL_DEVICE ? g_vtxProjected5[i][3] : g_vtxBuffer[i].rhw; 
             if( w < 0 || g_vtxBuffer[i].tcord[t].v > 1.0 || g_vtxBuffer[i].tcord[t].v < 0.0  )
@@ -1439,7 +1444,7 @@ bool SaveCITextureToFile(TxtrCacheEntry &entry, char *filename, bool bShow, bool
             if( entry.ti.Size == TXT_SIZE_4b )
             {
                 if( idx%8 ) idx = (idx/8+1)*8;
-        }
+            }
             else
             {
                 if( idx%4 ) idx = (idx/4+1)*4;
@@ -1451,7 +1456,8 @@ bool SaveCITextureToFile(TxtrCacheEntry &entry, char *filename, bool bShow, bool
     }
 
     // Create BMP color indexed file
-    if( strcasecmp(right(filename,4),".bmp") != 0 ) strcat(filename,".bmp");
+    if( strcasecmp(right(filename,4),".bmp") != 0 )
+        strcat(filename,".bmp");
 
     BITMAPFILEHEADER fileHeader;
     BITMAPINFOHEADER infoHeader;
@@ -1651,7 +1657,7 @@ void CRender::SaveTextureToFile(int tex, TextureChannel channel, bool bShow)
                 g_textures[tex].pTextureEntry->ti.Size, channel == TXT_ALPHA ? "a" : channel == TXT_RGBA ? "all" : "rgb");
             SaveTextureToFile(*pEnhancedTexture, filename, channel, true, true);
             DebuggerAppendMsg("Whole texture is stored at: %s", filename);
-    }
+        }
     }
 }
 #endif
@@ -1835,21 +1841,20 @@ void CRender::UpdateClipRectangle()
         gRSP.clip_ratio_bottom = centery + halfy * gRSP.clip_ratio_posy;
     }
 
-
     UpdateScissorWithClipRatio();
 }
 
 void CRender::UpdateScissorWithClipRatio()
 {
-    gRSP.real_clip_scissor_left = max(gRDP.scissor.left, gRSP.clip_ratio_left);
-    gRSP.real_clip_scissor_top = max(gRDP.scissor.top, gRSP.clip_ratio_top);
-    gRSP.real_clip_scissor_right = min(gRDP.scissor.right,gRSP.clip_ratio_right);
-    gRSP.real_clip_scissor_bottom = min(gRDP.scissor.bottom, gRSP.clip_ratio_bottom);
+    gRSP.real_clip_scissor_left = std::max(gRDP.scissor.left, gRSP.clip_ratio_left);
+    gRSP.real_clip_scissor_top = std::max(gRDP.scissor.top, gRSP.clip_ratio_top);
+    gRSP.real_clip_scissor_right = std::min(gRDP.scissor.right,gRSP.clip_ratio_right);
+    gRSP.real_clip_scissor_bottom = std::min(gRDP.scissor.bottom, gRSP.clip_ratio_bottom);
 
-    gRSP.real_clip_scissor_left = max(gRSP.real_clip_scissor_left, 0);
-    gRSP.real_clip_scissor_top = max(gRSP.real_clip_scissor_top, 0);
-    gRSP.real_clip_scissor_right = min(gRSP.real_clip_scissor_right,windowSetting.uViWidth-1);
-    gRSP.real_clip_scissor_bottom = min(gRSP.real_clip_scissor_bottom, windowSetting.uViHeight-1);
+    gRSP.real_clip_scissor_left = std::max(gRSP.real_clip_scissor_left, 0);
+    gRSP.real_clip_scissor_top = std::max(gRSP.real_clip_scissor_top, 0);
+    gRSP.real_clip_scissor_right = std::min(gRSP.real_clip_scissor_right,windowSetting.uViWidth-1);
+    gRSP.real_clip_scissor_bottom = std::min(gRSP.real_clip_scissor_bottom, windowSetting.uViHeight-1);
 
     WindowSettingStruct &w = windowSetting;
     w.clipping.left = (uint32)(gRSP.real_clip_scissor_left*windowSetting.fMultX);
@@ -1882,7 +1887,8 @@ void CRender::UpdateScissorWithClipRatio()
 }
 
 
-void CRender::InitOtherModes(void)                  // Set other modes not covered by color combiner or alpha blender
+// Set other modes not covered by color combiner or alpha blender
+void CRender::InitOtherModes(void)
 {
     ApplyTextureFilter();
 
