@@ -137,7 +137,7 @@ TLITVERTEX          g_clippedVtxBuffer[2000];
 uint8               g_oglVtxColors[1000][4];
 int                 g_clippedVtxCount=0;
 TLITVERTEX          g_texRectTVtx[4];
-unsigned int        g_vtxIndex[1000];
+unsigned short      g_vtxIndex[1000];
 unsigned int        g_minIndex, g_maxIndex;
 
 float               gRSPfFogMin;
@@ -170,76 +170,76 @@ n.z = (g_normal.x * matWorld.m02) + (g_normal.y * matWorld.m12) + (g_normal.z *
 // Multiply (x,y,z,0) by matrix m, then normalize
 #if defined(__INTEL_COMPILER) && !defined(NO_ASM)
 #define Vec3TransformNormal(vec, m) __asm                   \
-{                                                       \
-    __asm fld       dword ptr [vec + 0]                         \
-    __asm fmul  dword ptr [m + 0]           /* x m00*/      \
-    __asm fld       dword ptr [vec + 0]                         \
-    __asm fmul  dword ptr [m + 4]   /* x m01  x m00*/           \
-    __asm fld       dword ptr [vec + 0]                             \
-    __asm fmul  dword ptr [m + 8]   /* x m02  x m01  x m00*/    \
-    \
-    __asm fld       dword ptr [vec + 4]                             \
-    __asm fmul  dword ptr [m + 16]  /* y m10  x m02  x m01  x m00*/ \
-    __asm fld       dword ptr [vec + 4]                                 \
-    __asm fmul  dword ptr [m + 20]  /* y m11  y m10  x m02  x m01  x m00*/      \
-    __asm fld       dword ptr [vec + 4]                                             \
-    __asm fmul  dword ptr [m + 24]  /* y m12  y m11  y m10  x m02  x m01  x m00*/   \
-    \
-    __asm fxch  st(2)               /* y m10  y m11  y m12  x m02  x m01  x m00*/           \
-    __asm faddp st(5), st(0)        /* y m11  y m12  x m02  x m01  (x m00 + y m10)*/        \
-    __asm faddp st(3), st(0)        /* y m12  x m02  (x m01 + ym11)  (x m00 + y m10)*/  \
-    __asm faddp st(1), st(0)        /* (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/    \
-    \
-    __asm fld       dword ptr [vec + 8]                                                     \
-    __asm fmul  dword ptr [m + 32] /* z m20  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/  \
-    __asm fld       dword ptr [vec + 8]                                                             \
-    __asm fmul  dword ptr [m + 36] /* z m21  z m20  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/               \
-    __asm fld       dword ptr [vec + 8]                                                                             \
-    __asm fmul  dword ptr [m + 40] /* z m22  z m21  z m20  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/        \
-    \
-    __asm fxch  st(2)               /* z m20  z m21  z m22  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/       \
-    __asm faddp st(5), st(0)        /* z m21  z m22  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10 + z m20)*/  \
-    __asm faddp st(3), st(0)        /* z m22  (x m02 + y m12) (x m01 + ym11 + z m21)  (x m00 + y m10 + z m20)*/ \
-    __asm faddp st(1), st(0)        /* (x m02 + y m12 + z m 22) (x m01 + ym11 + z m21)  (x m00 + y m10 + z m20)*/   \
-    \
-    __asm fxch  st(2)               /* (x m00 + y m10 + z m20) (x m01 + ym11 + z m21) (x m02 + y m12 + z m 22) */   \
-    \
-    __asm fld1                      /* 1 x y z */ \
-    __asm fld   st(1)               /* x 1 x y z */ \
-    __asm fmul  st(0),st(0)         /* xx 1 x y z */  \
-    __asm fld   st(3)               /* y xx 1 x y z */ \
-    __asm fmul  st(0),st(0)         /* yy xx 1 x y z */ \
-    __asm fld   st(5)               /* z yy xx 1 x y z */ \
-    __asm fmul  st(0),st(0)         /* zz yy xx 1 x y z */ \
-    \
-    __asm fxch  st(2)               /* xx yy zz 1 x y z */ \
-    \
-    __asm faddp st(1),st(0)         /* (xx+yy) zz 1 x y z */ \
-    __asm faddp st(1),st(0)         /* (xx+yy+zz) 1 x y z */ \
-    \
-    __asm ftst                      /* Compare ST to 0  */              \
-    __asm fstsw ax                  /* Store FPU status word in a   */  \
-    __asm sahf                      /* Transfer ax to flags register */ \
-    __asm jz        l2              /* Skip if length is zero   */      \
-    \
-    __asm fsqrt                     /* l 1 x y z */ \
-    \
-    __asm fdivp st(1),st(0)         /* (1/l) x y z */ \
-    \
-    __asm fmul  st(3),st(0)         /* f x y fz */                                      \
-    __asm fmul  st(2),st(0)         /* f x fy fz */                                     \
-    __asm fmulp st(1),st(0)         /* fx fy fz */                                      \
-    \
-    __asm fstp  dword ptr [vec + 0] /* fy fz*/                          \
-    __asm fstp  dword ptr [vec + 4] /* fz   */          \
-    __asm fstp  dword ptr [vec + 8] /* done */          \
-    __asm jmp   l3  \
-__asm l2:   \
+{                                       \
+    __asm fld   dword ptr [vec + 0]     \
+    __asm fmul  dword ptr [m + 0]       \ /* x m00*/
+    __asm fld   dword ptr [vec + 0]     \
+    __asm fmul  dword ptr [m + 4]       \ /* x m01  x m00*/
+    __asm fld   dword ptr [vec + 0]     \
+    __asm fmul  dword ptr [m + 8]       \ /* x m02  x m01  x m00*/
+                                        \
+    __asm fld   dword ptr [vec + 4]     \
+    __asm fmul  dword ptr [m + 16]      \ /* y m10  x m02  x m01  x m00*/
+    __asm fld   dword ptr [vec + 4]     \
+    __asm fmul  dword ptr [m + 20]      \ /* y m11  y m10  x m02  x m01  x m00*/
+    __asm fld   dword ptr [vec + 4]     \
+    __asm fmul  dword ptr [m + 24]      \ /* y m12  y m11  y m10  x m02  x m01  x m00*/
+                                        \
+    __asm fxch  st(2)                   \ /* y m10  y m11  y m12  x m02  x m01  x m00*/
+    __asm faddp st(5), st(0)            \ /* y m11  y m12  x m02  x m01  (x m00 + y m10)*/
+    __asm faddp st(3), st(0)            \ /* y m12  x m02  (x m01 + ym11)  (x m00 + y m10)*/
+    __asm faddp st(1), st(0)            \ /* (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/
+                                        \
+    __asm fld   dword ptr [vec + 8]     \
+    __asm fmul  dword ptr [m + 32]      \ /* z m20  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/
+    __asm fld   dword ptr [vec + 8]     \
+    __asm fmul  dword ptr [m + 36]      \ /* z m21  z m20  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/
+    __asm fld   dword ptr [vec + 8]     \
+    __asm fmul  dword ptr [m + 40]      \ /* z m22  z m21  z m20  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/
+                                        \
+    __asm fxch  st(2)                   \ /* z m20  z m21  z m22  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10)*/
+    __asm faddp st(5), st(0)            \ /* z m21  z m22  (x m02 + y m12) (x m01 + ym11)  (x m00 + y m10 + z m20)*/ 
+    __asm faddp st(3), st(0)            \ /* z m22  (x m02 + y m12) (x m01 + ym11 + z m21)  (x m00 + y m10 + z m20)*/
+    __asm faddp st(1), st(0)            \ /* (x m02 + y m12 + z m 22) (x m01 + ym11 + z m21)  (x m00 + y m10 + z m20)*/
+                                        \
+    __asm fxch  st(2)                   \ /* (x m00 + y m10 + z m20) (x m01 + ym11 + z m21) (x m02 + y m12 + z m 22) */
+                                        \
+    __asm fld1                          \ /* 1 x y z */
+    __asm fld   st(1)                   \ /* x 1 x y z */
+    __asm fmul  st(0),st(0)             \ /* xx 1 x y z */
+    __asm fld   st(3)                   \ /* y xx 1 x y z */
+    __asm fmul  st(0),st(0)             \ /* yy xx 1 x y z */
+    __asm fld   st(5)                   \ /* z yy xx 1 x y z */
+    __asm fmul  st(0),st(0)             \ /* zz yy xx 1 x y z */
+                                        \
+    __asm fxch  st(2)                   \ /* xx yy zz 1 x y z */
+                                        \
+    __asm faddp st(1),st(0)             \ /* (xx+yy) zz 1 x y z */
+    __asm faddp st(1),st(0)             \ /* (xx+yy+zz) 1 x y z */
+                                        \
+    __asm ftst                          \ /* Compare ST to 0  */
+    __asm fstsw ax                      \ /* Store FPU status word in a   */
+    __asm sahf                          \ /* Transfer ax to flags register */
+    __asm jz        l2                  \ /* Skip if length is zero   */
+                                        \
+    __asm fsqrt                         \ /* l 1 x y z */
+                                        \
+    __asm fdivp st(1),st(0)             \ /* (1/l) x y z */
+                                        \
+    __asm fmul  st(3),st(0)             \ /* f x y fz */
+    __asm fmul  st(2),st(0)             \ /* f x fy fz */
+    __asm fmulp st(1),st(0)             \ /* fx fy fz */
+                                        \
+    __asm fstp  dword ptr [vec + 0]     \ /* fy fz*/
+    __asm fstp  dword ptr [vec + 4]     \ /* fz   */
+    __asm fstp  dword ptr [vec + 8]     \ /* done */
+    __asm jmp   l3                      \
+__asm l2:                               \
     __asm mov dword ptr [vec + 0], 0    \
     __asm mov dword ptr [vec + 4], 0    \
     __asm mov dword ptr [vec + 8], 0    \
-__asm l3:   \
-}       \
+__asm l3:                               \
+}                                       \
 
 #else  // use C code in other cases, this is probably faster anyway
 #define Vec3TransformNormal(vec, m) \
@@ -384,7 +384,7 @@ __declspec( naked ) void  __fastcall SSEVec3TransformDKR(XVECTOR4 &pOut, const X
 void SSEVec3Transform(int i)
 {
   asm volatile(" shl               $4,      %0   \n"
-               " movsxl           %k0,     %q0   \n"
+               " movslq           %k0,     %q0   \n"
                " movaps      (%1,%q0),  %%xmm1   \n"
                " movaps         0(%2),  %%xmm4   \n"
                " movaps        16(%2),  %%xmm5   \n"
@@ -725,12 +725,11 @@ void InitRenderBase()
     memset(&gRDP.otherMode,0,sizeof(RDP_OtherMode));
     memset(&gRDP.tiles,0,sizeof(Tile)*8);
 
-
-        int i;
-    for( i=0; i<MAX_VERTS; i++ )
+    for( int i=0; i<MAX_VERTS; i++ )
+    {
         g_clipFlag[i] = 0;
-    for( i=0; i<MAX_VERTS; i++ )
         g_vtxNonTransformed[i].w = 1;
+    }
 
     memset(gRSPn64lights, 0, sizeof(N64Light)*16);
 }
@@ -863,7 +862,9 @@ void InitVertex(uint32 dwV, uint32 vtxIndex, bool bTexture, bool openGL)
         g_vtxProjected5[vtxIndex][3] = g_vtxTransformed[dwV].w;
         g_vtxProjected5[vtxIndex][4] = g_vecProjected[dwV].z;
 
-        if( g_vtxTransformed[dwV].w < 0 )   g_vtxProjected5[vtxIndex][4] = 0;
+        if( g_vtxTransformed[dwV].w < 0 )
+            g_vtxProjected5[vtxIndex][4] = 0;
+
         g_vtxIndex[vtxIndex] = vtxIndex;
     }
 
@@ -1071,7 +1072,6 @@ uint32 LightVert(XVECTOR4 & norm, int vidx)
                     g += gRSPlights[l].fg * fCosT;
                     b += gRSPlights[l].fb * fCosT;
                 }
-
             }
         }
     }
@@ -1154,11 +1154,11 @@ breakout:
         minps       xmm0,xmm3;
 
         // Without using a memory
-        cvtss2si    eax,xmm0;   // move the 1st uint32 to eax
+        cvtss2si    eax,xmm0;       // move the 1st uint32 to eax
         shl         eax,10h;
         or          eax,0FF000000h;
         shufps      xmm0,xmm0,0E5h; // move the 2nd uint32 to the 1st uint32
-        cvtss2si    ecx,xmm0;   // move the 1st uint32 to ecx
+        cvtss2si    ecx,xmm0;       // move the 1st uint32 to ecx
         shl         ecx,8;
         or          eax,ecx;
         shufps      xmm0,xmm0,0E6h; // Move the 3rd uint32 to the 1st uint32
@@ -1174,8 +1174,8 @@ uint32 SSELightVert(void)
   uint32 rval;
   float f255 = 255.0, fZero = 0.0;
   
-  asm volatile(" movaps            %1,  %%xmm3    \n" // xmm3 == gRSP.fAmbientLight{RGBA}
-           " movaps            %2,  %%xmm4    \n"     // xmm4 == g_normal.{xyz}
+  asm volatile(" movaps        %1,  %%xmm3    \n" // xmm3 == gRSP.fAmbientLight{RGBA}
+           " movaps            %2,  %%xmm4    \n" // xmm4 == g_normal.{xyz}
            " xor            %%rcx,   %%rcx    \n"
            "0:                                \n"
            " cmpl              %3,   %%ecx    \n"
@@ -1316,8 +1316,7 @@ void ProcessVertexDataSSE(uint32 dwAddr, uint32 dwV0, uint32 dwNum)
     FiddledVtx * pVtxBase = (FiddledVtx*)(g_pRDRAMu8 + dwAddr);
     g_pVtxBase = pVtxBase;
 
-    uint32 i;
-    for (i = dwV0; i < dwV0 + dwNum; i++)
+    for (uint32 i = dwV0; i < dwV0 + dwNum; i++)
     {
         SP_Timing(RSP_GBI0_Vtx);
 
@@ -1426,8 +1425,7 @@ void ProcessVertexDataNoSSE(uint32 dwAddr, uint32 dwV0, uint32 dwNum)
     FiddledVtx * pVtxBase = (FiddledVtx*)(g_pRDRAMu8 + dwAddr);
     g_pVtxBase = pVtxBase;
 
-    uint32 i;
-    for (i = dwV0; i < dwV0 + dwNum; i++)
+    for (uint32 i = dwV0; i < dwV0 + dwNum; i++)
     {
         SP_Timing(RSP_GBI0_Vtx);
 
@@ -1593,8 +1591,6 @@ bool IsTriangleVisible(uint32 dwV0, uint32 dwV1, uint32 dwV2)
             float fDirection = (V1 * W2) - (V2 * W1);
             fDirection = fDirection * v1.w * v2.w * v0.w;
             //float fDirection = v0.x*v1.y-v1.x*v0.y+v1.x*v2.y-v2.x*v1.y+v2.x*v0.y-v0.x*v2.y;
-            /*
-            */
 
             if (fDirection < 0 && gRSP.bCullBack)
             {
@@ -1634,10 +1630,10 @@ void SetPrimitiveColor(uint32 dwCol, uint32 LODMin, uint32 LODFrac)
         gRDP.primLODFrac = gRDP.primLODMin;
     }
 
-    gRDP.fvPrimitiveColor[0] = ((dwCol>>16)&0xFF)/255.0f;       //r
-    gRDP.fvPrimitiveColor[1] = ((dwCol>>8)&0xFF)/255.0f;        //g
-    gRDP.fvPrimitiveColor[2] = ((dwCol)&0xFF)/255.0f;           //b
-    gRDP.fvPrimitiveColor[3] = ((dwCol>>24)&0xFF)/255.0f;       //a
+    gRDP.fvPrimitiveColor[0] = ((dwCol>>16)&0xFF)/255.0f;  //r
+    gRDP.fvPrimitiveColor[1] = ((dwCol>>8)&0xFF)/255.0f;   //g
+    gRDP.fvPrimitiveColor[2] = ((dwCol)&0xFF)/255.0f;      //b
+    gRDP.fvPrimitiveColor[3] = ((dwCol>>24)&0xFF)/255.0f;  //a
 }
 
 void SetPrimitiveDepth(uint32 z, uint32 dwDZ)
@@ -1745,12 +1741,11 @@ void ProcessVertexDataDKR(uint32 dwAddr, uint32 dwV0, uint32 dwNum)
 {
     UpdateCombinedMatrix();
 
-    long pVtxBase = (long) (g_pRDRAMu8 + dwAddr);
+    long long pVtxBase = (long long) (g_pRDRAMu8 + dwAddr);
     g_pVtxBase = (FiddledVtx*)pVtxBase;
 
     Matrix &matWorldProject = gRSP.DKRMatrixes[gRSP.DKRCMatrixIndex];
 
-    uint32 i;
     int nOff;
 
     bool addbase=false;
@@ -1769,7 +1764,7 @@ void ProcessVertexDataDKR(uint32 dwAddr, uint32 dwV0, uint32 dwNum)
 
     nOff = 0;
     uint32 end = dwV0 + dwNum;
-    for (i = dwV0; i < end; i++)
+    for (uint32 i = dwV0; i < end; i++)
     {
         XVECTOR3 w;
 
@@ -1980,8 +1975,7 @@ void ProcessVertexDataConker(uint32 dwAddr, uint32 dwV0, uint32 dwNum)
     g_pVtxBase = pVtxBase;
     //short *vertexColoraddr = (short*)(g_pRDRAMu8+dwConkerVtxZAddr);
 
-    uint32 i;
-    for (i = dwV0; i < dwV0 + dwNum; i++)
+    for (uint32 i = dwV0; i < dwV0 + dwNum; i++)
     {
         SP_Timing(RSP_GBI0_Vtx);
 
@@ -2109,7 +2103,7 @@ typedef union {
         uint8 r;
     };
     struct {
-        char na;
+        char na;    //a
         char nz;    //b
         char ny;    //g
         char nx;    //r
@@ -2312,7 +2306,9 @@ void ForceMainTextureIndex(int dwTile)
         gRSP.curTile = 0;
     }
     else
+    {
         gRSP.curTile = dwTile;
+    }
 }
 
 float HackZ2(float z)
