@@ -17,7 +17,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <SDL_opengl.h>
+#include "osal_opengl.h"
 #include "OGLDebug.h"
 #include "FrameBuffer.h"
 #include "Render.h"
@@ -82,18 +82,17 @@ void CRender::LoadFrameBuffer(bool useVIreg, uint32 left, uint32 top, uint32 wid
             gti.LeftToLoad      = left;
             gti.TopToLoad       = top;
 
-            gti.WidthToCreate       = width;
-            gti.HeightToCreate      = height;
+            gti.WidthToCreate   = width;
+            gti.HeightToCreate  = height;
         }
 
         if( gti.Size == TXT_SIZE_4b )
         {
-            gti.Pitch   = g_CI.dwWidth >> 1;
+            gti.Pitch = g_CI.dwWidth >> 1;
         }
         else
         {
-            gti.Pitch   = g_CI.dwWidth << (gti.Size-1);
-
+            gti.Pitch = g_CI.dwWidth << (gti.Size-1);
         }
     }
 
@@ -130,12 +129,12 @@ void CRender::LoadTextureFromMemory(void *buf, uint32 left, uint32 top, uint32 w
     gti.Palette = 0;
     gti.TLutFmt = TLUT_FMT_RGBA16;  //RGBA16
     gti.PalAddress = 0;
-    gti.bSwapped    = FALSE;
+    gti.bSwapped = FALSE;
     gti.Address = 0;
-    gti.LeftToLoad      = 0;
-    gti.TopToLoad       = 0;
-    gti.WidthToCreate       = width;
-    gti.HeightToCreate      = height;
+    gti.LeftToLoad = 0;
+    gti.TopToLoad = 0;
+    gti.WidthToCreate = width;
+    gti.HeightToCreate = height;
 
     gti.Pitch   = pitch;
 
@@ -868,13 +867,6 @@ void CRender::LoadObjSprite(uObjTxSprite &sprite, bool useTIAddr)
     gti.Format  = sprite.sprite.imageFmt;
     gti.Size    = sprite.sprite.imageSiz;
 
-    uint8* img;
-    if( useTIAddr )
-    {
-        img = (uint8*)(g_pRDRAMu8+RSPSegmentAddr(g_TI.dwAddr));
-    }
-    else
-        img = (uint8*)(g_pRDRAMu8+RSPSegmentAddr(sprite.txtr.block.image));
     uchar *palAddr = (uchar *) &g_wRDPTlut[0];
 
     gti.Address = RSPSegmentAddr(sprite.txtr.block.image);
