@@ -37,8 +37,6 @@ inline int GetNextPrime(int nFirst)
 {
     int nCurrent;
 
-    int i;
-
     nCurrent = nFirst;
 
     // Just make sure it's odd
@@ -53,11 +51,10 @@ inline int GetNextPrime(int nFirst)
         // nSqrtCurrent = nCurrent^0.5 + 1 (round up)
         nSqrtCurrent = (int)sqrt((double)nCurrent) + 1;
 
-
         bIsComposite = FALSE;
         
         // Test all odd numbers from 3..nSqrtCurrent
-        for (i = 3; i <= nSqrtCurrent; i+=2)
+        for (int i = 3; i <= nSqrtCurrent; i+=2)
         {
             if ((nCurrent % i) == 0)
             {
@@ -74,7 +71,6 @@ inline int GetNextPrime(int nFirst)
         // Select next odd candidate...
         nCurrent += 2;
     }
-
 }
 
 
@@ -124,13 +120,13 @@ bool CTextureManager::CleanUp()
 
     if (!g_bUseSetTextureMem)
     {
-    while (m_pHead)
-    {
-        TxtrCacheEntry * pVictim = m_pHead;
-        m_pHead = pVictim->pNext;
+        while (m_pHead)
+        {
+            TxtrCacheEntry * pVictim = m_pHead;
+            m_pHead = pVictim->pNext;
 
-        delete pVictim;
-    }
+            delete pVictim;
+        }
     }
 
     if( m_blackTextureEntry.pTexture )      delete m_blackTextureEntry.pTexture;    
@@ -149,11 +145,13 @@ bool CTextureManager::CleanUp()
 
 bool CTextureManager::TCacheEntryIsLoaded(TxtrCacheEntry *pEntry)
 {
-  for (int i = 0; i < MAX_TEXTURES; i++)
-    if (g_textures[i].pTextureEntry == pEntry)
-      return true;
+    for (int i = 0; i < MAX_TEXTURES; i++)
+    {
+        if (g_textures[i].pTextureEntry == pEntry)
+            return true;
+    }
 
-  return false;
+    return false;
 }
 
 // Purge any textures whos last usage was over 5 seconds ago
@@ -410,7 +408,7 @@ TxtrCacheEntry * CTextureManager::GetTxtrCacheEntry(TxtrInfo * pti)
         {
             MakeTextureYoungest(pEntry);
             return pEntry;
-    }
+        }
     }
 
     return NULL;
@@ -694,7 +692,7 @@ TxtrCacheEntry * CTextureManager::GetTexture(TxtrInfo * pgti, bool fromTMEM, boo
         }
         else
         {
-            ; //Do something
+            //Do something
         }
     }
 
@@ -718,23 +716,23 @@ TxtrCacheEntry * CTextureManager::GetTexture(TxtrInfo * pgti, bool fromTMEM, boo
     pEntry->bExternalTxtrChecked = false;
     pEntry->maxCI = maxCI;
 
-    if( pEntry->pTexture->m_dwCreatedTextureWidth < pgti->WidthToCreate )
-    {
-        pEntry->ti.WidthToLoad = pEntry->pTexture->m_dwCreatedTextureWidth;
-        pEntry->pTexture->m_bScaledS = false;
-        pEntry->pTexture->m_bScaledT = false;
-    }
-    if( pEntry->pTexture->m_dwCreatedTextureHeight < pgti->HeightToCreate )
-    {
-        pEntry->ti.HeightToLoad = pEntry->pTexture->m_dwCreatedTextureHeight;
-        pEntry->pTexture->m_bScaledT = false;
-        pEntry->pTexture->m_bScaledS = false;
-    }
-
     try 
     {
         if (pEntry->pTexture != NULL)
         {
+            if( pEntry->pTexture->m_dwCreatedTextureWidth < pgti->WidthToCreate )
+            {
+                pEntry->ti.WidthToLoad = pEntry->pTexture->m_dwCreatedTextureWidth;
+                pEntry->pTexture->m_bScaledS = false;
+                pEntry->pTexture->m_bScaledT = false;
+            }
+            if( pEntry->pTexture->m_dwCreatedTextureHeight < pgti->HeightToCreate )
+            {
+                pEntry->ti.HeightToLoad = pEntry->pTexture->m_dwCreatedTextureHeight;
+                pEntry->pTexture->m_bScaledT = false;
+                pEntry->pTexture->m_bScaledS = false;
+            }
+            
             TextureFmt dwType = pEntry->pTexture->GetSurfaceFormat();
             SAFE_DELETE(pEntry->pEnhancedTexture);
             pEntry->dwEnhancementFlag = TEXTURE_NO_ENHANCEMENT;
@@ -1542,6 +1540,7 @@ void ConvertTextureRGBAtoI(TxtrCacheEntry* pEntry, bool alpha)
                 buf[nX] = (a|(i<<16)|(i<<8)|i);
             }
         }
-        pEntry->pTexture->EndUpdate(&srcInfo);  }
+        pEntry->pTexture->EndUpdate(&srcInfo);
+    }
 }
 
