@@ -37,8 +37,8 @@ void InitBMGImage( struct BMGImageStruct *img )
     img->bits_per_pixel = 0;
     img->palette_size = 0;
     img->bytes_per_palette_entry = 0;
-    img->bits = 0;
-    img->palette = 0;
+    img->bits = NULL;
+    img->palette = NULL;
     img->opt_for_bmp = 0;
     img->scan_width = 0;
     img->transparency_index = -1;
@@ -47,15 +47,15 @@ void InitBMGImage( struct BMGImageStruct *img )
 /* frees memory allocated to a BMGImage */
 void FreeBMGImage( struct BMGImageStruct *img )
 {
-    if ( img->bits != 0 )
+    if ( img->bits != NULL )
     {
         free( img->bits );
-        img->bits = 0;
+        img->bits = NULL;
     }
-    if ( img->palette != 0 )
+    if ( img->palette != NULL )
     {
         free( img->palette );
-        img->palette = 0;
+        img->palette = NULL;
     }
     img->bits_per_pixel = 0;
     img->palette_size = 0;
@@ -99,15 +99,15 @@ BMGError AllocateBMGImage( struct BMGImageStruct *img )
     }
 
     /* delete old memory */
-    if ( img->bits != 0 )
+    if ( img->bits != NULL )
     {
         free( img->bits );
-        img->bits = 0;
+        img->bits = NULL;
     }
-    if ( img->palette != 0 )
+    if ( img->palette != NULL )
     {
         free( img->palette );
-        img->palette = 0;
+        img->palette = NULL;
     }
 
     /* allocate memory for the palette */
@@ -132,7 +132,7 @@ BMGError AllocateBMGImage( struct BMGImageStruct *img )
 
         mempal = img->bytes_per_palette_entry * img->palette_size;
         img->palette = (unsigned char *)calloc( mempal, sizeof(unsigned char) );
-        if ( img->palette == 0 )
+        if ( img->palette == NULL )
         {
             SetLastBMGError(errMemoryAllocation);
             return errMemoryAllocation;
@@ -157,12 +157,12 @@ BMGError AllocateBMGImage( struct BMGImageStruct *img )
     if ( mempal > 0 )
     {
         img->bits = (unsigned char *)calloc( mempal, sizeof( unsigned char) );
-        if ( img->bits == 0 )
+        if ( img->bits == NULL )
         {
-            if ( img->palette != 0 )
+            if ( img->palette != NULL )
             {
                 free( img->palette );
-                img->palette = 0;
+                img->palette = NULL;
             }
             SetLastBMGError(errMemoryAllocation);
             return errMemoryAllocation;
@@ -189,7 +189,7 @@ BMGError CompressBMGImage( struct BMGImageStruct *img )
 {
     unsigned char new_bits_per_pixel;
     unsigned int new_scan_width;
-    unsigned char *new_bits = 0;
+    unsigned char *new_bits = NULL;
     unsigned int new_bit_size;
     unsigned char *new_row, *old_row, *p, *q;
     unsigned char *end;
@@ -198,7 +198,7 @@ BMGError CompressBMGImage( struct BMGImageStruct *img )
     SetLastBMGError( BMG_OK );
 
     /* if we cannot compress it then do no harm and return "true" */
-    if ( img->palette == 0 ||
+    if ( img->palette == NULL ||
          img->palette_size > 16 ||
          img->bits_per_pixel != 8 )
     {
@@ -214,7 +214,7 @@ BMGError CompressBMGImage( struct BMGImageStruct *img )
 
     /* allocate & test memory */
     new_bits = (unsigned char *)calloc( new_bit_size, sizeof(unsigned char) );
-    if ( new_bits == 0 )
+    if ( new_bits == NULL )
     {
         SetLastBMGError( errMemoryAllocation );
         return errMemoryAllocation;
@@ -290,13 +290,13 @@ BMGError CompressBMGImage( struct BMGImageStruct *img )
    applications */
 void FreeBMGMemory( unsigned char *mem )
 {
-    if ( mem != 0 )
+    if ( mem != NULL )
         free( mem );
 }
 
 /* converts a BGR to a gray scale
 // color[0] = blue, color[1] = green, color[2] = red */
-unsigned char CreateGrayScale( unsigned char *color )
+static unsigned char CreateGrayScale( unsigned char *color )
 {
     return (unsigned char)( 0.299f * color[2] + 0.587f * color[1]
                                + 0.114f * color[0] + 0.5f );
@@ -354,7 +354,7 @@ BMGError ConvertToGrayScale( struct BMGImageStruct *img )
         /* allocate memory for the new pixel values */
         new_bits = (unsigned char *)calloc( new_scan_width * img->height,
                     sizeof(unsigned char) );
-        if ( new_bits == 0 )
+        if ( new_bits == NULL )
         {
             SetLastBMGError( errMemoryAllocation );
             return errMemoryAllocation;
@@ -367,7 +367,7 @@ BMGError ConvertToGrayScale( struct BMGImageStruct *img )
             (unsigned char *)calloc(img->bytes_per_palette_entry *
                                     img->palette_size,
                                     sizeof(unsigned char) );
-        if ( img->palette == 0 )
+        if ( img->palette == NULL )
         {
             free( new_bits );
             img->bytes_per_palette_entry = 0;
